Welcome to PyAnsys Templates
============================

The ``PyAnsys Templates`` holds a collection of useful templates compliant with
the PyAnsys guidelines. It provides the ``ansys-templates`` command line tool
for interactively generating new projects based on previous templates.

Main advantages of using this tool are:

- Building process is fully interactive: no need to manually modifying files!
- Customize output project during rendering process.
- Generated projects are compliant with `PyAnsys Developer's Guidelines`_.

.. _PyAnsys Developer's Guidelines: https://dev.docs.pyansys.com/

To use this tool, reference its documentation at `PyAnsys Template Documentation`_.

.. _PyAnsys Template Documentation: https://templates.pyansys.com/ 
